@@ -3,8 +3,8 @@
 
 # Importing the necessary packages
 import numpy as np
-from .convenience import readToGray
-from .convenience import saveNumpy
+from .utils import readToGray
+from .utils import saveNumpy
 
 
 def preprocess(DIR, categories, size, isSave=True ):
@@ -98,4 +98,4 @@ def imageDataGenerator():
     # We do not augment the validation data
     val_datagen = ImageDataGenerator()
 
-    return train_datagen, val_datagen
\ No newline at end of file
+    return train_datagen, val_datagen
